@@ -31,18 +31,26 @@
 #include "socket_poller.hpp"
 #include "err.hpp"
 
+#include <limits.h>
+
+static bool is_thread_safe (zmq::socket_base_t &socket_)
+{
+    // do not use getsockopt here, since that would fail during context termination
+    return socket_.is_thread_safe ();
+}
+
 zmq::socket_poller_t::socket_poller_t () :
-    tag (0xCAFEBABE),
-    signaler (NULL),
-    need_rebuild (true),
-    use_signaler (false),
-    poll_size(0)
+    _tag (0xCAFEBABE),
+    _signaler (NULL),
+    _need_rebuild (true),
+    _use_signaler (false),
+    _pollset_size (0)
 #if defined ZMQ_POLL_BASED_ON_POLL
     ,
-    pollfds (NULL)
+    _pollfds (NULL)
 #elif defined ZMQ_POLL_BASED_ON_SELECT
     ,
-    maxfd(0)
+    _max_fd (0)
 #endif
 {
 #if defined ZMQ_POLL_BASED_ON_SELECT
@@ -50,13 +58,13 @@ zmq::socket_poller_t::socket_poller_t () :
     // On Windows fd_set contains array of SOCKETs, each 4 bytes.
     // For large fd_sets memset() could be expensive and it is unnecessary.
     // It is enough to set fd_count to 0, exactly what FD_ZERO() macro does.
-    FD_ZERO (&pollset_in);
-    FD_ZERO (&pollset_out);
-    FD_ZERO (&pollset_err);
+    FD_ZERO (&_pollset_in);
+    FD_ZERO (&_pollset_out);
+    FD_ZERO (&_pollset_err);
 #else
-    memset(&pollset_in, 0, sizeof(pollset_in));
-    memset(&pollset_out, 0, sizeof(pollset_out));
-    memset(&pollset_err, 0, sizeof(pollset_err));
+    memset (&_pollset_in, 0, sizeof (_pollset_in));
+    memset (&_pollset_out, 0, sizeof (_pollset_out));
+    memset (&_pollset_err, 0, sizeof (_pollset_err));
 #endif
 #endif
 }
@@ -64,107 +72,132 @@ zmq::socket_poller_t::socket_poller_t () :
 zmq::socket_poller_t::~socket_poller_t ()
 {
     //  Mark the socket_poller as dead
-    tag = 0xdeadbeef;
+    _tag = 0xdeadbeef;
 
-    for (items_t::iterator it = items.begin(); it != items.end(); ++it) {
-        if (it->socket && it->socket->check_tag()) {
-            int thread_safe;
-            size_t thread_safe_size = sizeof(int);
-
-            if (it->socket->getsockopt (ZMQ_THREAD_SAFE, &thread_safe, &thread_safe_size) == 0 && thread_safe)
-                it->socket->remove_signaler (signaler);
+    for (items_t::iterator it = _items.begin (); it != _items.end (); ++it) {
+        // TODO shouldn't this zmq_assert (it->socket->check_tag ()) instead?
+        if (it->socket && it->socket->check_tag ()
+            && is_thread_safe (*it->socket)) {
+            it->socket->remove_signaler (_signaler);
         }
     }
 
-    if (signaler != NULL) {
-        delete signaler;
-        signaler = NULL;
+    if (_signaler != NULL) {
+        delete _signaler;
+        _signaler = NULL;
     }
 
 #if defined ZMQ_POLL_BASED_ON_POLL
-    if (pollfds) {
-        free (pollfds);
-        pollfds = NULL;
+    if (_pollfds) {
+        free (_pollfds);
+        _pollfds = NULL;
     }
 #endif
 }
 
 bool zmq::socket_poller_t::check_tag ()
 {
-    return tag == 0xCAFEBABE;
+    return _tag == 0xCAFEBABE;
 }
 
-int zmq::socket_poller_t::add (socket_base_t *socket_, void* user_data_, short events_)
+int zmq::socket_poller_t::add (socket_base_t *socket_,
+                               void *user_data_,
+                               short events_)
 {
-    for (items_t::iterator it = items.begin (); it != items.end (); ++it) {
+    for (items_t::iterator it = _items.begin (); it != _items.end (); ++it) {
         if (it->socket == socket_) {
             errno = EINVAL;
             return -1;
         }
     }
 
-    int thread_safe;
-    size_t thread_safe_size = sizeof(int);
+    if (is_thread_safe (*socket_)) {
+        if (_signaler == NULL) {
+            _signaler = new (std::nothrow) signaler_t ();
+            if (!_signaler) {
+                errno = ENOMEM;
+                return -1;
+            }
+            if (!_signaler->valid ()) {
+                delete _signaler;
+                _signaler = NULL;
+                errno = EMFILE;
+                return -1;
+            }
+        }
 
-    int rc =
-      socket_->getsockopt (ZMQ_THREAD_SAFE, &thread_safe, &thread_safe_size);
-    zmq_assert (rc == 0);
-
-    if (thread_safe) {
-        if (signaler == NULL)
-            signaler = new signaler_t ();
-
-        rc = socket_->add_signaler (signaler);
-        zmq_assert (rc == 0);
+        socket_->add_signaler (_signaler);
     }
 
-    item_t item = {socket_, 0, user_data_, events_
+    item_t item = {
+        socket_,
+        0,
+        user_data_,
+        events_
 #if defined ZMQ_POLL_BASED_ON_POLL
-                   ,-1
+        ,
+        -1
 #endif
     };
-    items.push_back (item);
-    need_rebuild = true;
+    try {
+        _items.push_back (item);
+    }
+    catch (const std::bad_alloc &) {
+        errno = ENOMEM;
+        return -1;
+    }
+    _need_rebuild = true;
 
     return 0;
 }
 
 int zmq::socket_poller_t::add_fd (fd_t fd_, void *user_data_, short events_)
 {
-   for (items_t::iterator it = items.begin (); it != items.end (); ++it) {
+    for (items_t::iterator it = _items.begin (); it != _items.end (); ++it) {
         if (!it->socket && it->fd == fd_) {
             errno = EINVAL;
             return -1;
         }
     }
 
-    item_t item = {NULL, fd_, user_data_, events_
+    item_t item = {
+        NULL,
+        fd_,
+        user_data_,
+        events_
 #if defined ZMQ_POLL_BASED_ON_POLL
-                   ,-1
+        ,
+        -1
 #endif
-                   };
-    items.push_back (item);
-    need_rebuild = true;
+    };
+    try {
+        _items.push_back (item);
+    }
+    catch (const std::bad_alloc &) {
+        errno = ENOMEM;
+        return -1;
+    }
+    _need_rebuild = true;
 
     return 0;
 }
 
-int zmq::socket_poller_t::modify (socket_base_t  *socket_, short events_)
+int zmq::socket_poller_t::modify (socket_base_t *socket_, short events_)
 {
     items_t::iterator it;
 
-    for (it = items.begin (); it != items.end (); ++it) {
+    for (it = _items.begin (); it != _items.end (); ++it) {
         if (it->socket == socket_)
             break;
     }
 
-    if (it == items.end()) {
+    if (it == _items.end ()) {
         errno = EINVAL;
         return -1;
     }
 
     it->events = events_;
-    need_rebuild = true;
+    _need_rebuild = true;
 
     return 0;
 }
@@ -174,18 +207,18 @@ int zmq::socket_poller_t::modify_fd (fd_t fd_, short events_)
 {
     items_t::iterator it;
 
-    for (it = items.begin (); it != items.end (); ++it) {
+    for (it = _items.begin (); it != _items.end (); ++it) {
         if (!it->socket && it->fd == fd_)
             break;
     }
 
-    if (it == items.end()) {
+    if (it == _items.end ()) {
         errno = EINVAL;
         return -1;
     }
 
     it->events = events_;
-    need_rebuild = true;
+    _need_rebuild = true;
 
     return 0;
 }
@@ -195,24 +228,22 @@ int zmq::socket_poller_t::remove (socket_base_t *socket_)
 {
     items_t::iterator it;
 
-    for (it = items.begin (); it != items.end (); ++it) {
+    for (it = _items.begin (); it != _items.end (); ++it) {
         if (it->socket == socket_)
             break;
     }
 
-    if (it == items.end()) {
+    if (it == _items.end ()) {
         errno = EINVAL;
         return -1;
     }
 
-    items.erase(it);
-    need_rebuild = true;
+    _items.erase (it);
+    _need_rebuild = true;
 
-    int thread_safe;
-    size_t thread_safe_size = sizeof(int);
-
-    if (socket_->getsockopt (ZMQ_THREAD_SAFE, &thread_safe, &thread_safe_size) == 0 && thread_safe)
-        socket_->remove_signaler (signaler);
+    if (is_thread_safe (*socket_)) {
+        socket_->remove_signaler (_signaler);
+    }
 
     return 0;
 }
@@ -221,18 +252,18 @@ int zmq::socket_poller_t::remove_fd (fd_t fd_)
 {
     items_t::iterator it;
 
-    for (it = items.begin (); it != items.end (); ++it) {
+    for (it = _items.begin (); it != _items.end (); ++it) {
         if (!it->socket && it->fd == fd_)
             break;
     }
 
-    if (it == items.end()) {
+    if (it == _items.end ()) {
         errno = EINVAL;
         return -1;
     }
 
-    items.erase (it);
-    need_rebuild = true;
+    _items.erase (it);
+    _need_rebuild = true;
 
     return 0;
 }
@@ -241,172 +272,136 @@ void zmq::socket_poller_t::rebuild ()
 {
 #if defined ZMQ_POLL_BASED_ON_POLL
 
-    if (pollfds) {
-        free (pollfds);
-        pollfds = NULL;
+    if (_pollfds) {
+        free (_pollfds);
+        _pollfds = NULL;
     }
 
-    use_signaler = false;
+    _use_signaler = false;
 
-    poll_size = 0;
+    _pollset_size = 0;
 
-    for (items_t::iterator it = items.begin (); it != items.end (); ++it) {
+    for (items_t::iterator it = _items.begin (); it != _items.end (); ++it) {
         if (it->events) {
-            if (it->socket) {
-                int thread_safe;
-                size_t thread_safe_size = sizeof(int);
-
-                int rc = it->socket->getsockopt (ZMQ_THREAD_SAFE, &thread_safe,
-                                                 &thread_safe_size);
-                zmq_assert (rc == 0);
-
-                if (thread_safe) {
-                    if (!use_signaler) {
-                        use_signaler = true;
-                        poll_size++;
-                    }
+            if (it->socket && is_thread_safe (*it->socket)) {
+                if (!_use_signaler) {
+                    _use_signaler = true;
+                    _pollset_size++;
                 }
-                else
-                    poll_size++;
-            }
-            else
-                poll_size++;
+            } else
+                _pollset_size++;
         }
     }
 
-    if (poll_size == 0)
+    if (_pollset_size == 0)
         return;
 
-    pollfds = (pollfd*) malloc (poll_size * sizeof (pollfd));
-    alloc_assert (pollfds);
+    _pollfds = static_cast<pollfd *> (malloc (_pollset_size * sizeof (pollfd)));
+    alloc_assert (_pollfds);
 
     int item_nbr = 0;
 
-    if (use_signaler) {
+    if (_use_signaler) {
         item_nbr = 1;
-        pollfds[0].fd = signaler->get_fd();
-        pollfds[0].events = POLLIN;
+        _pollfds[0].fd = _signaler->get_fd ();
+        _pollfds[0].events = POLLIN;
     }
 
-    for (items_t::iterator it = items.begin (); it != items.end (); ++it) {
+    for (items_t::iterator it = _items.begin (); it != _items.end (); ++it) {
         if (it->events) {
             if (it->socket) {
-                int thread_safe;
-                size_t thread_safe_size = sizeof(int);
-
-                int rc = it->socket->getsockopt (ZMQ_THREAD_SAFE, &thread_safe,
-                                                 &thread_safe_size);
-                zmq_assert (rc == 0);
-
-                if (!thread_safe) {
+                if (!is_thread_safe (*it->socket)) {
                     size_t fd_size = sizeof (zmq::fd_t);
-                    rc = it->socket->getsockopt (ZMQ_FD, &pollfds [item_nbr].fd, &fd_size);
+                    int rc = it->socket->getsockopt (
+                      ZMQ_FD, &_pollfds[item_nbr].fd, &fd_size);
                     zmq_assert (rc == 0);
 
-                    pollfds [item_nbr].events = POLLIN;
+                    _pollfds[item_nbr].events = POLLIN;
                     item_nbr++;
                 }
-            }
-            else {
-                pollfds [item_nbr].fd = it->fd;
-                pollfds [item_nbr].events =
-                    (it->events & ZMQ_POLLIN ? POLLIN : 0) |
-                    (it->events & ZMQ_POLLOUT ? POLLOUT : 0) |
-                    (it->events & ZMQ_POLLPRI ? POLLPRI : 0);
+            } else {
+                _pollfds[item_nbr].fd = it->fd;
+                _pollfds[item_nbr].events =
+                  (it->events & ZMQ_POLLIN ? POLLIN : 0)
+                  | (it->events & ZMQ_POLLOUT ? POLLOUT : 0)
+                  | (it->events & ZMQ_POLLPRI ? POLLPRI : 0);
                 it->pollfd_index = item_nbr;
                 item_nbr++;
             }
         }
     }
 
- #elif defined ZMQ_POLL_BASED_ON_SELECT
+#elif defined ZMQ_POLL_BASED_ON_SELECT
 
-    FD_ZERO (&pollset_in);
-    FD_ZERO (&pollset_out);
-    FD_ZERO (&pollset_err);
+    FD_ZERO (&_pollset_in);
+    FD_ZERO (&_pollset_out);
+    FD_ZERO (&_pollset_err);
 
     //  Ensure we do not attempt to select () on more than FD_SETSIZE
     //  file descriptors.
-    zmq_assert (items.size () <= FD_SETSIZE);
+    zmq_assert (_items.size () <= FD_SETSIZE);
 
-    poll_size = 0;
+    _pollset_size = 0;
 
-    use_signaler = false;
+    _use_signaler = false;
 
-    for (items_t::iterator it = items.begin (); it != items.end (); ++it) {
-        if (it->socket) {
-            int thread_safe;
-            size_t thread_safe_size = sizeof(int);
-
-            int rc = it->socket->getsockopt (ZMQ_THREAD_SAFE, &thread_safe,
-                                             &thread_safe_size);
-            zmq_assert (rc == 0);
-
-            if (thread_safe && it->events) {
-                use_signaler = true;
-                FD_SET (signaler->get_fd (), &pollset_in);
-                poll_size = 1;
-                break;
-            }
+    for (items_t::iterator it = _items.begin (); it != _items.end (); ++it) {
+        if (it->socket && is_thread_safe (*it->socket) && it->events) {
+            _use_signaler = true;
+            FD_SET (_signaler->get_fd (), &_pollset_in);
+            _pollset_size = 1;
+            break;
         }
     }
 
-    maxfd = 0;
+    _max_fd = 0;
 
     //  Build the fd_sets for passing to select ().
-    for (items_t::iterator it = items.begin (); it != items.end (); ++it) {
+    for (items_t::iterator it = _items.begin (); it != _items.end (); ++it) {
         if (it->events) {
             //  If the poll item is a 0MQ socket we are interested in input on the
             //  notification file descriptor retrieved by the ZMQ_FD socket option.
             if (it->socket) {
-                int thread_safe;
-                size_t thread_safe_size = sizeof(int);
-
-                int rc = it->socket->getsockopt (ZMQ_THREAD_SAFE, &thread_safe,
-                                                 &thread_safe_size);
-                zmq_assert (rc == 0);
-
-                if (!thread_safe) {
+                if (!is_thread_safe (*it->socket)) {
                     zmq::fd_t notify_fd;
                     size_t fd_size = sizeof (zmq::fd_t);
-                    rc = it->socket->getsockopt (ZMQ_FD, &notify_fd, &fd_size);
+                    int rc =
+                      it->socket->getsockopt (ZMQ_FD, &notify_fd, &fd_size);
                     zmq_assert (rc == 0);
 
-                    FD_SET (notify_fd, &pollset_in);
-                    if (maxfd < notify_fd)
-                        maxfd = notify_fd;
+                    FD_SET (notify_fd, &_pollset_in);
+                    if (_max_fd < notify_fd)
+                        _max_fd = notify_fd;
 
-                    poll_size++;
+                    _pollset_size++;
                 }
             }
             //  Else, the poll item is a raw file descriptor. Convert the poll item
             //  events to the appropriate fd_sets.
             else {
                 if (it->events & ZMQ_POLLIN)
-                    FD_SET (it->fd, &pollset_in);
+                    FD_SET (it->fd, &_pollset_in);
                 if (it->events & ZMQ_POLLOUT)
-                    FD_SET (it->fd, &pollset_out);
+                    FD_SET (it->fd, &_pollset_out);
                 if (it->events & ZMQ_POLLERR)
-                    FD_SET (it->fd, &pollset_err);
-                if (maxfd < it->fd)
-                    maxfd = it->fd;
+                    FD_SET (it->fd, &_pollset_err);
+                if (_max_fd < it->fd)
+                    _max_fd = it->fd;
 
-                poll_size++;
+                _pollset_size++;
             }
         }
     }
 
 #endif
 
-    need_rebuild = false;
+    _need_rebuild = false;
 }
 
 void zmq::socket_poller_t::zero_trail_events (
-                                         zmq::socket_poller_t::event_t *events_,
-                                         int n_events_,
-                                         int found)
+  zmq::socket_poller_t::event_t *events_, int n_events_, int found_)
 {
-    for (int i = found; i < n_events_; ++i) {
+    for (int i = found_; i < n_events_; ++i) {
         events_[i].socket = NULL;
         events_[i].fd = 0;
         events_[i].user_data = NULL;
@@ -416,26 +411,25 @@ void zmq::socket_poller_t::zero_trail_events (
 
 #if defined ZMQ_POLL_BASED_ON_POLL
 int zmq::socket_poller_t::check_events (zmq::socket_poller_t::event_t *events_,
-                                                              int n_events_)
+                                        int n_events_)
 #elif defined ZMQ_POLL_BASED_ON_SELECT
 int zmq::socket_poller_t::check_events (zmq::socket_poller_t::event_t *events_,
-                                                              int n_events_,
-                                                              fd_set& inset,
-                                                              fd_set& outset,
-                                                              fd_set& errset)
+                                        int n_events_,
+                                        fd_set &inset_,
+                                        fd_set &outset_,
+                                        fd_set &errset_)
 #endif
 {
     int found = 0;
-    for (items_t::iterator it = items.begin (); it != items.end () &&
-                                                  found < n_events_; ++it) {
-
+    for (items_t::iterator it = _items.begin ();
+         it != _items.end () && found < n_events_; ++it) {
         //  The poll item is a 0MQ socket. Retrieve pending events
         //  using the ZMQ_EVENTS socket option.
         if (it->socket) {
             size_t events_size = sizeof (uint32_t);
             uint32_t events;
             if (it->socket->getsockopt (ZMQ_EVENTS, &events, &events_size)
-                                                                        == -1) {
+                == -1) {
                 return -1;
             }
 
@@ -449,10 +443,9 @@ int zmq::socket_poller_t::check_events (zmq::socket_poller_t::event_t *events_,
         //  Else, the poll item is a raw file descriptor, simply convert
         //  the events to zmq_pollitem_t-style format.
         else {
-
 #if defined ZMQ_POLL_BASED_ON_POLL
 
-            short revents = pollfds [it->pollfd_index].revents;
+            short revents = _pollfds[it->pollfd_index].revents;
             short events = 0;
 
             if (revents & POLLIN)
@@ -468,11 +461,11 @@ int zmq::socket_poller_t::check_events (zmq::socket_poller_t::event_t *events_,
 
             short events = 0;
 
-            if (FD_ISSET (it->fd, &inset))
+            if (FD_ISSET (it->fd, &inset_))
                 events |= ZMQ_POLLIN;
-            if (FD_ISSET (it->fd, &outset))
+            if (FD_ISSET (it->fd, &outset_))
                 events |= ZMQ_POLLOUT;
-            if (FD_ISSET (it->fd, &errset))
+            if (FD_ISSET (it->fd, &errset_))
                 events |= ZMQ_POLLERR;
 #endif //POLL_SELECT
 
@@ -490,12 +483,12 @@ int zmq::socket_poller_t::check_events (zmq::socket_poller_t::event_t *events_,
 }
 
 //Return 0 if timeout is expired otherwise 1
-int zmq::socket_poller_t::adjust_timeout (zmq::clock_t& clock, long timeout_,
-                                                              uint64_t& now,
-                                                              uint64_t& end,
-                                                              bool& first_pass)
+int zmq::socket_poller_t::adjust_timeout (zmq::clock_t &clock_,
+                                          long timeout_,
+                                          uint64_t &now_,
+                                          uint64_t &end_,
+                                          bool &first_pass_)
 {
-
     //  If socket_poller_t::timeout is zero, exit immediately whether there
     //  are events or not.
     if (timeout_ == 0)
@@ -504,8 +497,8 @@ int zmq::socket_poller_t::adjust_timeout (zmq::clock_t& clock, long timeout_,
     //  At this point we are meant to wait for events but there are none.
     //  If timeout is infinite we can just loop until we get some events.
     if (timeout_ < 0) {
-        if (first_pass)
-            first_pass = false;
+        if (first_pass_)
+            first_pass_ = false;
         return 1;
     }
 
@@ -513,33 +506,33 @@ int zmq::socket_poller_t::adjust_timeout (zmq::clock_t& clock, long timeout_,
     //  we get a timestamp of when the polling have begun. (We assume that
     //  first pass have taken negligible time). We also compute the time
     //  when the polling should time out.
-    now = clock.now_ms ();
-    if (first_pass) {
-        end = now + timeout_;
-        first_pass = false;
+    now_ = clock_.now_ms ();
+    if (first_pass_) {
+        end_ = now_ + timeout_;
+        first_pass_ = false;
         return 1;
     }
 
     //  Find out whether timeout have expired.
-    if (now >= end)
+    if (now_ >= end_)
         return 0;
 
     return 1;
 }
 
 int zmq::socket_poller_t::wait (zmq::socket_poller_t::event_t *events_,
-                                                         int n_events_,
-                                                         long timeout_)
+                                int n_events_,
+                                long timeout_)
 {
-    if (items.empty () && timeout_ < 0) {
+    if (_items.empty () && timeout_ < 0) {
         errno = EFAULT;
         return -1;
     }
 
-    if (need_rebuild)
+    if (_need_rebuild)
         rebuild ();
 
-    if (unlikely (poll_size == 0)) {
+    if (unlikely (_pollset_size == 0)) {
         // We'll report an error (timed out) as if the list was non-empty and
         // no event occurred within the specified timeout. Otherwise the caller
         // needs to check the return value AND the event to avoid using the
@@ -553,6 +546,16 @@ int zmq::socket_poller_t::wait (zmq::socket_poller_t::event_t *events_,
 #elif defined ZMQ_HAVE_ANDROID
         usleep (timeout_ * 1000);
         return -1;
+#elif defined ZMQ_HAVE_OSX
+        usleep (timeout_ * 1000);
+        errno = EAGAIN;
+        return -1;
+#elif defined ZMQ_HAVE_VXWORKS
+        struct timespec ns_;
+        ns_.tv_sec = timeout_ / 1000;
+        ns_.tv_nsec = timeout_ % 1000 * 1000000;
+        nanosleep (&ns_, 0);
+        return -1;
 #else
         usleep (timeout_ * 1000);
         return -1;
@@ -571,15 +574,15 @@ int zmq::socket_poller_t::wait (zmq::socket_poller_t::event_t *events_,
         int timeout;
         if (first_pass)
             timeout = 0;
-        else
-        if (timeout_ < 0)
+        else if (timeout_ < 0)
             timeout = -1;
         else
-            timeout = end - now;
+            timeout =
+              static_cast<int> (std::min<uint64_t> (end - now, INT_MAX));
 
         //  Wait for events.
         while (true) {
-            int rc = poll (pollfds, poll_size, timeout);
+            int rc = poll (_pollfds, _pollset_size, timeout);
             if (rc == -1 && errno == EINTR) {
                 return -1;
             }
@@ -588,8 +591,8 @@ int zmq::socket_poller_t::wait (zmq::socket_poller_t::event_t *events_,
         }
 
         //  Receive the signal from pollfd
-        if (use_signaler && pollfds[0].revents & POLLIN)
-            signaler->recv ();
+        if (_use_signaler && _pollfds[0].revents & POLLIN)
+            _signaler->recv ();
 
         //  Check for the events.
         int found = check_events (events_, n_events_);
@@ -617,7 +620,6 @@ int zmq::socket_poller_t::wait (zmq::socket_poller_t::event_t *events_,
     fd_set inset, outset, errset;
 
     while (true) {
-
         //  Compute the timeout for the subsequent poll.
         timeval timeout;
         timeval *ptimeout;
@@ -625,13 +627,11 @@ int zmq::socket_poller_t::wait (zmq::socket_poller_t::event_t *events_,
             timeout.tv_sec = 0;
             timeout.tv_usec = 0;
             ptimeout = &timeout;
-        }
-        else
-        if (timeout_ < 0)
+        } else if (timeout_ < 0)
             ptimeout = NULL;
         else {
-            timeout.tv_sec = (long) ((end - now) / 1000);
-            timeout.tv_usec = (long) ((end - now) % 1000 * 1000);
+            timeout.tv_sec = static_cast<long> ((end - now) / 1000);
+            timeout.tv_usec = static_cast<long> ((end - now) % 1000 * 1000);
             ptimeout = &timeout;
         }
 
@@ -642,9 +642,18 @@ int zmq::socket_poller_t::wait (zmq::socket_poller_t::event_t *events_,
             // SOCKETS are continuous from the beginning of fd_array in fd_set.
             // We just need to copy fd_count elements of fd_array.
             // We gain huge memcpy() improvement if number of used SOCKETs is much lower than FD_SETSIZE.
-            memcpy (&inset,  &pollset_in,  (char *) (pollset_in.fd_array  + pollset_in.fd_count ) - (char *) &pollset_in );
-            memcpy (&outset, &pollset_out, (char *) (pollset_out.fd_array + pollset_out.fd_count) - (char *) &pollset_out);
-            memcpy (&errset, &pollset_err, (char *) (pollset_err.fd_array + pollset_err.fd_count) - (char *) &pollset_err);
+            memcpy (&inset, &_pollset_in,
+                    reinterpret_cast<char *> (_pollset_in.fd_array
+                                              + _pollset_in.fd_count)
+                      - reinterpret_cast<char *> (&_pollset_in));
+            memcpy (&outset, &_pollset_out,
+                    reinterpret_cast<char *> (_pollset_out.fd_array
+                                              + _pollset_out.fd_count)
+                      - reinterpret_cast<char *> (&_pollset_out));
+            memcpy (&errset, &_pollset_err,
+                    reinterpret_cast<char *> (_pollset_err.fd_array
+                                              + _pollset_err.fd_count)
+                      - reinterpret_cast<char *> (&_pollset_err));
             int rc = select (0, &inset, &outset, &errset, ptimeout);
             if (unlikely (rc == SOCKET_ERROR)) {
                 errno = zmq::wsa_error_to_errno (WSAGetLastError ());
@@ -652,10 +661,10 @@ int zmq::socket_poller_t::wait (zmq::socket_poller_t::event_t *events_,
                 return -1;
             }
 #else
-            memcpy (&inset, &pollset_in, sizeof (fd_set));
-            memcpy (&outset, &pollset_out, sizeof (fd_set));
-            memcpy (&errset, &pollset_err, sizeof (fd_set));
-            int rc = select (maxfd + 1, &inset, &outset, &errset, ptimeout);
+            memcpy (&inset, &_pollset_in, sizeof (fd_set));
+            memcpy (&outset, &_pollset_out, sizeof (fd_set));
+            memcpy (&errset, &_pollset_err, sizeof (fd_set));
+            int rc = select (_max_fd + 1, &inset, &outset, &errset, ptimeout);
             if (unlikely (rc == -1)) {
                 errno_assert (errno == EINTR || errno == EBADF);
                 return -1;
@@ -664,11 +673,11 @@ int zmq::socket_poller_t::wait (zmq::socket_poller_t::event_t *events_,
             break;
         }
 
-        if (use_signaler && FD_ISSET (signaler->get_fd (), &inset))
-            signaler->recv ();
+        if (_use_signaler && FD_ISSET (_signaler->get_fd (), &inset))
+            _signaler->recv ();
 
         //  Check for the events.
-        int found = check_events(events_, n_events_, inset, outset, errset);
+        int found = check_events (events_, n_events_, inset, outset, errset);
         if (found) {
             if (found > 0)
                 zero_trail_events (events_, n_events_, found);
